@@ -11,11 +11,12 @@ import inspect
 import logging
 from typing import Any, Final, cast
 
-from aiohomematic import central as hmcu, client as hmcl
+from aiohomematic import central as hmcu, client as hmcl, i18n
 from aiohomematic.central import rpc_server as rpc
 from aiohomematic.const import BackendSystemEvent
 from aiohomematic.exceptions import AioHomematicException
 from aiohomematic.support import extract_exc_args
+from aiohomematic.type_aliases import CallableAny, CallableNone
 
 _LOGGER: Final = logging.getLogger(__name__)
 _INTERFACE_ID: Final = "interface_id"
@@ -24,7 +25,7 @@ _PARAMETER: Final = "parameter"
 _VALUE: Final = "value"
 
 
-def callback_backend_system(system_event: BackendSystemEvent) -> Callable:
+def callback_backend_system(system_event: BackendSystemEvent) -> Callable[[CallableAny], CallableAny]:
     """Check if backend_system_callback is set and call it AFTER original function."""
 
     def decorator_backend_system_callback[**P, R](
@@ -57,8 +58,10 @@ def callback_backend_system(system_event: BackendSystemEvent) -> Callable:
                     )
             except Exception as exc:
                 _LOGGER.warning(
-                    "EXEC_BACKEND_SYSTEM_CALLBACK failed: Problem with identifying central: %s",
-                    extract_exc_args(exc=exc),
+                    i18n.tr(
+                        "exception.central.decorators.backend_system_callback.identify_central_failed",
+                        reason=extract_exc_args(exc=exc),
+                    )
                 )
             return return_value
 
@@ -66,7 +69,9 @@ def callback_backend_system(system_event: BackendSystemEvent) -> Callable:
             """Execute the callback for a system event."""
 
             if not ((len(args) > 1 and not kwargs) or (len(args) == 1 and kwargs)):
-                _LOGGER.warning("EXEC_BACKEND_SYSTEM_CALLBACK failed: *args not supported for callback_system_event")
+                _LOGGER.error(  # i18n-log: ignore
+                    "EXEC_BACKEND_SYSTEM_CALLBACK failed: *args not supported for callback_system_event"
+                )
             try:
                 args = args[1:]
                 interface_id: str = args[0] if len(args) > 0 else str(kwargs[_INTERFACE_ID])
@@ -74,11 +79,14 @@ def callback_backend_system(system_event: BackendSystemEvent) -> Callable:
                     client.modified_at = datetime.now()
                     client.central.emit_backend_system_callback(system_event=system_event, **kwargs)
             except Exception as exc:  # pragma: no cover
-                _LOGGER.warning(
+                _LOGGER.error(  # i18n-log: ignore
                     "EXEC_BACKEND_SYSTEM_CALLBACK failed: Unable to reduce kwargs for backend_system_callback"
                 )
                 raise AioHomematicException(
-                    f"args-exception backend_system_callback [{extract_exc_args(exc=exc)}]"
+                    i18n.tr(
+                        "exception.central.decorators.backend_system_callback.args_exception",
+                        reason=extract_exc_args(exc=exc),
+                    )
                 ) from exc
 
         if inspect.iscoroutinefunction(func):
@@ -88,7 +96,7 @@ def callback_backend_system(system_event: BackendSystemEvent) -> Callable:
     return decorator_backend_system_callback
 
 
-def callback_event[**P, R](func: Callable[P, R]) -> Callable:
+def callback_event[**P, R](func: Callable[P, R]) -> Callable[P, R | Awaitable[R]]:
     """Check if event_callback is set and call it AFTER original function."""
 
     def _exec_event_callback(*args: Any, **kwargs: Any) -> None:
@@ -113,8 +121,15 @@ def callback_event[**P, R](func: Callable[P, R]) -> Callable:
                     interface_id=interface_id, channel_address=channel_address, parameter=parameter, value=value
                 )
         except Exception as exc:  # pragma: no cover
-            _LOGGER.warning("EXEC_DATA_POINT_EVENT_CALLBACK failed: Unable to process args/kwargs for event_callback")
-            raise AioHomematicException(f"args-exception event_callback [{extract_exc_args(exc=exc)}]") from exc
+            _LOGGER.error(  # i18n-log: ignore
+                "EXEC_DATA_POINT_EVENT_CALLBACK failed: Unable to process args/kwargs for event_callback"
+            )
+            raise AioHomematicException(
+                i18n.tr(
+                    "exception.central.decorators.event_callback.args_exception",
+                    reason=extract_exc_args(exc=exc),
+                )
+            ) from exc
 
     def _schedule_or_exec(*args: Any, **kwargs: Any) -> None:
         """Schedule event callback on central looper when possible, else execute inline."""
@@ -147,7 +162,7 @@ def callback_event[**P, R](func: Callable[P, R]) -> Callable:
         return return_value
 
     # Helper to create a trivial coroutine from a sync callable
-    async def _async_wrap_sync(cb: Callable[..., None], *a: Any, **kw: Any) -> None:
+    async def _async_wrap_sync(cb: CallableNone, *a: Any, **kw: Any) -> None:
         cb(*a, **kw)
 
     if inspect.iscoroutinefunction(func):
