@@ -8,7 +8,7 @@ Public API of this module is defined by __all__.
 
 from __future__ import annotations
 
-from collections.abc import Callable, Iterable, Mapping
+from collections.abc import Iterable, Mapping
 from dataclasses import dataclass, field
 from datetime import datetime
 from enum import Enum, IntEnum, StrEnum
@@ -17,9 +17,9 @@ import os
 import re
 import sys
 from types import MappingProxyType
-from typing import Any, Final, NamedTuple, Required, TypeAlias, TypedDict
+from typing import Any, Final, NamedTuple, Required, TypedDict
 
-VERSION: Final = "2025.10.25"
+VERSION: Final = "2025.11.17"
 
 # Detect test speedup mode via environment
 _TEST_SPEEDUP: Final = (
@@ -35,6 +35,7 @@ DEFAULT_HM_MASTER_POLL_AFTER_SEND_INTERVALS: Final = (5,)
 DEFAULT_IGNORE_CUSTOM_DEVICE_DEFINITION_MODELS: Final[frozenset[str]] = frozenset()
 DEFAULT_INCLUDE_INTERNAL_PROGRAMS: Final = False
 DEFAULT_INCLUDE_INTERNAL_SYSVARS: Final = True
+DEFAULT_LOCALE: Final = "en"
 DEFAULT_MAX_READ_WORKERS: Final = 1
 DEFAULT_MAX_WORKERS: Final = 1
 DEFAULT_MULTIPLIER: Final = 1.0
@@ -55,6 +56,8 @@ UTF_8: Final = "utf-8"
 # Default encoding for xmlrpc service calls and script files
 ISO_8859_1: Final = "iso-8859-1"
 
+BIDCOS_DEVICE_CHANNEL_DUMMY: Final = 999
+
 # Password can be empty.
 # Allowed characters: A-Z, a-z, 0-9, .!$():;#-
 # The CCU WebUI also supports ÄäÖöÜüß, but these characters are not supported by the XmlRPC servers
@@ -68,6 +71,7 @@ SCHEDULER_PROFILE_PATTERN: Final = re.compile(
     r"^P[1-6]_(ENDTIME|TEMPERATURE)_(MONDAY|TUESDAY|WEDNESDAY|THURSDAY|FRIDAY|SATURDAY|SUNDAY)_([1-9]|1[0-3])$"
 )
 SCHEDULER_TIME_PATTERN: Final = re.compile(r"^(([0-1]{0,1}[0-9])|(2[0-4])):[0-5][0-9]")
+WEEK_PROFILE_PATTERN: Final = re.compile(r".*WEEK_PROFILE$")
 
 ALWAYS_ENABLE_SYSVARS_BY_ID: Final[frozenset[str]] = frozenset({"40", "41"})
 RENAME_SYSVAR_BY_NAME: Final[Mapping[str, str]] = MappingProxyType(
@@ -145,8 +149,6 @@ SYSVAR_STATE_PATH_ROOT: Final = "sysvar/status"
 VIRTDEV_SET_PATH_ROOT: Final = "virtdev/set"
 VIRTDEV_STATE_PATH_ROOT: Final = "virtdev/status"
 
-CALLBACK_TYPE: TypeAlias = Callable[[], None] | None
-
 
 class Backend(StrEnum):
     """Enum with supported aiohomematic backends."""
@@ -191,6 +193,24 @@ class CalulatedParameter(StrEnum):
     VAPOR_CONCENTRATION = "VAPOR_CONCENTRATION"
 
 
+class CDPD(StrEnum):
+    """Enum for custom data point definitions."""
+
+    ADDITIONAL_DPS = "additional_dps"
+    ALLOW_UNDEFINED_GENERIC_DPS = "allow_undefined_generic_dps"
+    DEFAULT_DPS = "default_dps"
+    DEVICE_DEFINITIONS = "device_definitions"
+    DEVICE_GROUP = "device_group"
+    FIELDS = "fields"
+    INCLUDE_DEFAULT_DPS = "include_default_dps"
+    PRIMARY_CHANNEL = "primary_channel"
+    REPEATABLE_FIELDS = "repeatable_fields"
+    SECONDARY_CHANNELS = "secondary_channels"
+    STATE_CHANNEL = "state_channel"
+    VISIBLE_FIELDS = "visible_fields"
+    VISIBLE_REPEATABLE_FIELDS = "visible_repeatable_fields"
+
+
 class CentralUnitState(StrEnum):
     """Enum with central unit states."""
 
@@ -209,13 +229,6 @@ class CommandRxMode(StrEnum):
     WAKEUP = "WAKEUP"
 
 
-class InternalCustomID(StrEnum):
-    """Enum for Homematic internal custom IDs."""
-
-    DEFAULT = "cid_default"
-    MANU_TEMP = "cid_manu_temp"
-
-
 class DataOperationResult(Enum):
     """Enum with data operation results."""
 
@@ -256,6 +269,15 @@ class DataPointCategory(StrEnum):
     VALVE = "valve"
 
 
+class DataPointKey(NamedTuple):
+    """Key for data points."""
+
+    interface_id: str
+    channel_address: str
+    paramset_key: ParamsetKey
+    parameter: str
+
+
 class DataPointUsage(StrEnum):
     """Enum with usage information."""
 
@@ -292,6 +314,41 @@ class DeviceFirmwareState(StrEnum):
     BACKGROUND_UPDATE_NOT_SUPPORTED = "BACKGROUND_UPDATE_NOT_SUPPORTED"
 
 
+class DeviceProfile(StrEnum):
+    """Enum for device profiles."""
+
+    IP_BUTTON_LOCK = "IPButtonLock"
+    IP_COVER = "IPCover"
+    IP_DIMMER = "IPDimmer"
+    IP_DRG_DALI = "IPDRGDALI"
+    IP_FIXED_COLOR_LIGHT = "IPFixedColorLight"
+    IP_GARAGE = "IPGarage"
+    IP_HDM = "IPHdm"
+    IP_IRRIGATION_VALVE = "IPIrrigationValve"
+    IP_LOCK = "IPLock"
+    IP_RGBW_LIGHT = "IPRGBW"
+    IP_SIMPLE_FIXED_COLOR_LIGHT = "IPSimpleFixedColorLight"
+    IP_SIMPLE_FIXED_COLOR_LIGHT_WIRED = "IPSimpleFixedColorLightWired"
+    IP_SIREN = "IPSiren"
+    IP_SIREN_SMOKE = "IPSirenSmoke"
+    IP_SWITCH = "IPSwitch"
+    IP_THERMOSTAT = "IPThermostat"
+    IP_THERMOSTAT_GROUP = "IPThermostatGroup"
+    RF_BUTTON_LOCK = "RFButtonLock"
+    RF_COVER = "RfCover"
+    RF_DIMMER = "RfDimmer"
+    RF_DIMMER_COLOR = "RfDimmer_Color"
+    RF_DIMMER_COLOR_FIXED = "RfDimmer_Color_Fixed"
+    RF_DIMMER_COLOR_TEMP = "RfDimmer_Color_Temp"
+    RF_DIMMER_WITH_VIRT_CHANNEL = "RfDimmerWithVirtChannel"
+    RF_LOCK = "RfLock"
+    RF_SIREN = "RfSiren"
+    RF_SWITCH = "RfSwitch"
+    RF_THERMOSTAT = "RfThermostat"
+    RF_THERMOSTAT_GROUP = "RfThermostatGroup"
+    SIMPLE_RF_THERMOSTAT = "SimpleRfThermostat"
+
+
 class EventKey(StrEnum):
     """Enum with aiohomematic event keys."""
 
@@ -320,6 +377,94 @@ class EventType(StrEnum):
     KEYPRESS = "homematic.keypress"
 
 
+class Field(Enum):
+    """Enum for fields."""
+
+    ACOUSTIC_ALARM_ACTIVE = "acoustic_alarm_active"
+    ACOUSTIC_ALARM_SELECTION = "acoustic_alarm_selection"
+    ACTIVE_PROFILE = "active_profile"
+    AUTO_MODE = "auto_mode"
+    BOOST_MODE = "boost_mode"
+    BUTTON_LOCK = "button_lock"
+    CHANNEL_COLOR = "channel_color"
+    COLOR = "color"
+    COLOR_BEHAVIOUR = "color_behaviour"
+    COLOR_LEVEL = "color_temp"
+    COLOR_TEMPERATURE = "color_temperature"
+    COMBINED_PARAMETER = "combined_parameter"
+    COMFORT_MODE = "comfort_mode"
+    CONCENTRATION = "concentration"
+    CONTROL_MODE = "control_mode"
+    CURRENT = "current"
+    DEVICE_OPERATION_MODE = "device_operation_mode"
+    DIRECTION = "direction"
+    DOOR_COMMAND = "door_command"
+    DOOR_STATE = "door_state"
+    DURATION = "duration"
+    DURATION_UNIT = "duration_unit"
+    DUTYCYCLE = "dutycycle"
+    DUTY_CYCLE = "duty_cycle"
+    EFFECT = "effect"
+    ENERGY_COUNTER = "energy_counter"
+    ERROR = "error"
+    FREQUENCY = "frequency"
+    GROUP_LEVEL = "group_level"
+    GROUP_LEVEL_2 = "group_level_2"
+    GROUP_STATE = "group_state"
+    HEATING_COOLING = "heating_cooling"
+    HEATING_VALVE_TYPE = "heating_valve_type"
+    HUE = "hue"
+    HUMIDITY = "humidity"
+    INHIBIT = "inhibit"
+    LEVEL = "level"
+    LEVEL_2 = "level_2"
+    LEVEL_COMBINED = "level_combined"
+    LOCK_STATE = "lock_state"
+    LOCK_TARGET_LEVEL = "lock_target_level"
+    LOWBAT = "lowbat"
+    LOWERING_MODE = "lowering_mode"
+    LOW_BAT = "low_bat"
+    LOW_BAT_LIMIT = "low_bat_limit"
+    MANU_MODE = "manu_mode"
+    MIN_MAX_VALUE_NOT_RELEVANT_FOR_MANU_MODE = "min_max_value_not_relevant_for_manu_mode"
+    ON_TIME_UNIT = "on_time_unit"
+    ON_TIME_VALUE = "on_time_value"
+    OPEN = "open"
+    OPERATING_VOLTAGE = "operating_voltage"
+    OPERATION_MODE = "channel_operation_mode"
+    OPTICAL_ALARM_ACTIVE = "optical_alarm_active"
+    OPTICAL_ALARM_SELECTION = "optical_alarm_selection"
+    OPTIMUM_START_STOP = "optimum_start_stop"
+    PARTY_MODE = "party_mode"
+    POWER = "power"
+    PROGRAM = "program"
+    RAMP_TIME_TO_OFF_UNIT = "ramp_time_to_off_unit"
+    RAMP_TIME_TO_OFF_VALUE = "ramp_time_to_off_value"
+    RAMP_TIME_UNIT = "ramp_time_unit"
+    RAMP_TIME_VALUE = "ramp_time_value"
+    RSSI_DEVICE = "rssi_device"
+    RSSI_PEER = "rssi_peer"
+    SABOTAGE = "sabotage"
+    SATURATION = "saturation"
+    SECTION = "section"
+    SETPOINT = "setpoint"
+    SET_POINT_MODE = "set_point_mode"
+    SMOKE_DETECTOR_ALARM_STATUS = "smoke_detector_alarm_status"
+    SMOKE_DETECTOR_COMMAND = "smoke_detector_command"
+    STATE = "state"
+    STOP = "stop"
+    SWITCH_MAIN = "switch_main"
+    SWITCH_V1 = "vswitch_1"
+    SWITCH_V2 = "vswitch_2"
+    TEMPERATURE = "temperature"
+    TEMPERATURE_MAXIMUM = "temperature_maximum"
+    TEMPERATURE_MINIMUM = "temperature_minimum"
+    TEMPERATURE_OFFSET = "temperature_offset"
+    VALVE_STATE = "valve_state"
+    VOLTAGE = "voltage"
+    WEEK_PROGRAM_POINTER = "week_program_pointer"
+
+
 class Flag(IntEnum):
     """Enum with Homematic flags."""
 
@@ -338,6 +483,14 @@ class ForcedDeviceAvailability(StrEnum):
     NOT_SET = "not_set"
 
 
+class InternalCustomID(StrEnum):
+    """Enum for Homematic internal custom IDs."""
+
+    DEFAULT = "cid_default"
+    LINK_PEER = "cid_link_peer"
+    MANU_TEMP = "cid_manu_temp"
+
+
 class Manufacturer(StrEnum):
     """Enum with aiohomematic system events."""
 
@@ -358,6 +511,7 @@ class Operations(IntEnum):
 class OptionalSettings(StrEnum):
     """Enum with aiohomematic optional settings."""
 
+    ENABLE_LINKED_ENTITY_CLIMATE_ACTIVITY = "ENABLE_LINKED_ENTITY_CLIMATE_ACTIVITY"
     SR_DISABLE_RANDOMIZE_OUTPUT = "SR_DISABLE_RANDOMIZED_OUTPUT"
     SR_RECORD_SYSTEM_INIT = "SR_RECORD_SYSTEM_INIT"
 
@@ -491,6 +645,7 @@ class ParamsetKey(StrEnum):
     """Enum with paramset keys."""
 
     CALCULATED = "CALCULATED"
+    DUMMY = "DUMMY"
     LINK = "LINK"
     MASTER = "MASTER"
     SERVICE = "SERVICE"
@@ -547,6 +702,19 @@ class InterfaceEventType(StrEnum):
     UNKNOWN_PONG = "unknown_pong"
 
 
+class ParameterType(StrEnum):
+    """Enum for Homematic parameter types."""
+
+    ACTION = "ACTION"  # Usually buttons, send Boolean to trigger
+    BOOL = "BOOL"
+    DUMMY = "DUMMY"
+    ENUM = "ENUM"
+    FLOAT = "FLOAT"
+    INTEGER = "INTEGER"
+    STRING = "STRING"
+    EMPTY = ""
+
+
 class ProxyInitState(Enum):
     """Enum with proxy handling results."""
 
@@ -557,6 +725,13 @@ class ProxyInitState(Enum):
     DE_INIT_SKIPPED = 16
 
 
+class RpcServerType(StrEnum):
+    """Enum for Homematic rpc server types."""
+
+    XML_RPC = "xml_rpc"
+    NONE = "none"
+
+
 class RxMode(IntEnum):
     """Enum for Homematic rx modes."""
 
@@ -590,25 +765,6 @@ class SysvarType(StrEnum):
     STRING = "STRING"
 
 
-class ParameterType(StrEnum):
-    """Enum for Homematic parameter types."""
-
-    ACTION = "ACTION"  # Usually buttons, send Boolean to trigger
-    BOOL = "BOOL"
-    ENUM = "ENUM"
-    FLOAT = "FLOAT"
-    INTEGER = "INTEGER"
-    STRING = "STRING"
-    EMPTY = ""
-
-
-class RpcServerType(StrEnum):
-    """Enum for Homematic rpc server types."""
-
-    XML_RPC = "xml_rpc"
-    NONE = "none"
-
-
 CLICK_EVENTS: Final[frozenset[Parameter]] = frozenset(
     {
         Parameter.PRESS,
@@ -632,15 +788,6 @@ DATA_POINT_EVENTS: Final[frozenset[EventType]] = frozenset(
 )
 
 
-class DataPointKey(NamedTuple):
-    """Key for data points."""
-
-    interface_id: str
-    channel_address: str
-    paramset_key: ParamsetKey
-    parameter: str
-
-
 type DP_KEY_VALUE = tuple[DataPointKey, Any]
 type SYSVAR_TYPE = bool | float | int | str | None
 
@@ -760,6 +907,14 @@ INTERFACE_RPC_SERVER_TYPE: Final[Mapping[Interface, RpcServerType]] = MappingPro
     }
 )
 
+LINKABLE_INTERFACES: Final[frozenset[Interface]] = frozenset(
+    {
+        Interface.BIDCOS_RF,
+        Interface.BIDCOS_WIRED,
+        Interface.HMIP_RF,
+    }
+)
+
 
 DEFAULT_USE_PERIODIC_SCAN_FOR_INTERFACES: Final = True
 
@@ -786,6 +941,55 @@ _IGNORE_ON_INITIAL_LOAD_PARAMETERS: Final[frozenset[Parameter]] = frozenset(
     }
 )
 
+_CLIMATE_SOURCE_ROLES: Final[tuple[str, ...]] = ("CLIMATE",)
+_CLIMATE_TARGET_ROLES: Final[tuple[str, ...]] = ("CLIMATE", "SWITCH", "LEVEL")
+_CLIMATE_TRANSMITTER_RE: Final = re.compile(r"(?:CLIMATE|HEATING).*(?:TRANSMITTER|TRANSCEIVER)")
+_CLIMATE_RECEIVER_RE: Final = re.compile(r"(?:CLIMATE|HEATING).*(?:TRANSCEIVER|RECEIVER)")
+
+
+def get_link_source_categories(
+    *, source_roles: tuple[str, ...], channel_type_name: str
+) -> tuple[DataPointCategory, ...]:
+    """Return the channel sender roles."""
+    result: set[DataPointCategory] = set()
+    has_climate = False
+    if _CLIMATE_TRANSMITTER_RE.search(channel_type_name):
+        result.add(DataPointCategory.CLIMATE)
+        has_climate = True
+
+    if not has_climate and source_roles and any("CLIMATE" in role for role in source_roles):
+        result.add(DataPointCategory.CLIMATE)
+
+    return tuple(result)
+
+
+def get_link_target_categories(
+    *, target_roles: tuple[str, ...], channel_type_name: str
+) -> tuple[DataPointCategory, ...]:
+    """Return the channel receiver roles."""
+    result: set[DataPointCategory] = set()
+    has_climate = False
+    if _CLIMATE_RECEIVER_RE.search(channel_type_name):
+        result.add(DataPointCategory.CLIMATE)
+        has_climate = True
+
+    if (
+        not has_climate
+        and target_roles
+        and any(cl_role in role for role in target_roles for cl_role in _CLIMATE_TARGET_ROLES)
+    ):
+        result.add(DataPointCategory.CLIMATE)
+
+    return tuple(result)
+
+
+RECEIVER_PARAMETERS: Final[frozenset[Parameter]] = frozenset(
+    {
+        Parameter.LEVEL,
+        Parameter.STATE,
+    }
+)
+
 
 def check_ignore_parameter_on_initial_load(parameter: str) -> bool:
     """Check if a parameter matches common wildcard patterns."""
@@ -886,32 +1090,32 @@ class DeviceDescription(TypedDict, total=False):
     """Typed dict for device descriptions."""
 
     TYPE: Required[str]
-    SUBTYPE: str | None
     ADDRESS: Required[str]
-    # RF_ADDRESS: int | None
+    PARAMSETS: Required[list[str]]
+    SUBTYPE: str | None
     CHILDREN: list[str]
     PARENT: str | None
-    # PARENT_TYPE: str | None
-    # INDEX: int | None
-    # AES_ACTIVE: int | None
-    PARAMSETS: list[str]
-    FIRMWARE: str
+    FIRMWARE: str | None
     AVAILABLE_FIRMWARE: str | None
     UPDATABLE: bool
     FIRMWARE_UPDATE_STATE: str | None
     FIRMWARE_UPDATABLE: bool | None
+    INTERFACE: str | None
+    RX_MODE: int | None
+    LINK_SOURCE_ROLES: str | None
+    LINK_TARGET_ROLES: str | None
+    # RF_ADDRESS: int | None
+    # PARENT_TYPE: str | None
+    # INDEX: int | None
+    # AES_ACTIVE: int | None
     # VERSION: Required[int]
     # FLAGS: Required[int]
-    # LINK_SOURCE_ROLES: str | None
-    # LINK_TARGET_ROLES: str | None
     # DIRECTION: int | None
     # GROUP: str | None
     # TEAM: str | None
     # TEAM_TAG: str | None
     # TEAM_CHANNELS: list
-    INTERFACE: str | None
     # ROAMING: int | None
-    RX_MODE: int
 
 
 # Define public API for this module
@@ -932,3 +1136,138 @@ __all__ = tuple(
         )
     )
 )
+
+
+class AstroType(IntEnum):
+    """Enum for astro event types."""
+
+    SUNRISE = 0
+    SUNSET = 1
+
+
+class ScheduleActorChannel(IntEnum):
+    """Enum for target actor channels (bitwise)."""
+
+    CHANNEL_1_1 = 1
+    CHANNEL_1_2 = 2
+    CHANNEL_1_3 = 4
+    CHANNEL_2_1 = 8
+    CHANNEL_2_2 = 16
+    CHANNEL_2_3 = 32
+    CHANNEL_3_1 = 64
+    CHANNEL_3_2 = 128
+    CHANNEL_3_3 = 256
+    CHANNEL_4_1 = 512
+    CHANNEL_4_2 = 1024
+    CHANNEL_4_3 = 2048
+    CHANNEL_5_1 = 4096
+    CHANNEL_5_2 = 8192
+    CHANNEL_5_3 = 16384
+    CHANNEL_6_1 = 32768
+    CHANNEL_6_2 = 65536
+    CHANNEL_6_3 = 131072
+    CHANNEL_7_1 = 262144
+    CHANNEL_7_2 = 524288
+    CHANNEL_7_3 = 1048576
+    CHANNEL_8_1 = 2097152
+    CHANNEL_8_2 = 4194304
+    CHANNEL_8_3 = 8388608
+
+
+class ScheduleCondition(IntEnum):
+    """Enum for schedule trigger conditions."""
+
+    FIXED_TIME = 0
+    ASTRO = 1
+
+
+class ScheduleField(StrEnum):
+    """Enum for switch schedule field names."""
+
+    ASTRO_OFFSET = "ASTRO_OFFSET"
+    ASTRO_TYPE = "ASTRO_TYPE"
+    CONDITION = "CONDITION"
+    DURATION_BASE = "DURATION_BASE"
+    DURATION_FACTOR = "DURATION_FACTOR"
+    FIXED_HOUR = "FIXED_HOUR"
+    FIXED_MINUTE = "FIXED_MINUTE"
+    LEVEL = "LEVEL"
+    LEVEL_2 = "LEVEL_2"
+    RAMP_TIME_BASE = "RAMP_TIME_BASE"
+    RAMP_TIME_FACTOR = "RAMP_TIME_FACTOR"
+    TARGET_CHANNELS = "TARGET_CHANNELS"
+    WEEKDAY = "WEEKDAY"
+
+
+class ScheduleSlotType(StrEnum):
+    """Enum for climate item type."""
+
+    ENDTIME = "ENDTIME"
+    STARTTIME = "STARTTIME"
+    TEMPERATURE = "TEMPERATURE"
+
+
+class ScheduleProfile(StrEnum):
+    """Enum for climate profiles."""
+
+    P1 = "P1"
+    P2 = "P2"
+    P3 = "P3"
+    P4 = "P4"
+    P5 = "P5"
+    P6 = "P6"
+
+
+class TimeBase(IntEnum):
+    """Enum for duration base units."""
+
+    MS_100 = 0  # 100 milliseconds
+    SEC_1 = 1  # 1 second
+    SEC_5 = 2  # 5 seconds
+    SEC_10 = 3  # 10 seconds
+    MIN_1 = 4  # 1 minute
+    MIN_5 = 5  # 5 minutes
+    MIN_10 = 6  # 10 minutes
+    HOUR_1 = 7  # 1 hour
+
+
+class WeekdayInt(IntEnum):
+    """Enum for weekdays (bitwise)."""
+
+    SUNDAY = 1
+    MONDAY = 2
+    TUESDAY = 4
+    WEDNESDAY = 8
+    THURSDAY = 16
+    FRIDAY = 32
+    SATURDAY = 64
+
+
+class WeekdayStr(StrEnum):
+    """Enum for climate week days."""
+
+    MONDAY = "MONDAY"
+    TUESDAY = "TUESDAY"
+    WEDNESDAY = "WEDNESDAY"
+    THURSDAY = "THURSDAY"
+    FRIDAY = "FRIDAY"
+    SATURDAY = "SATURDAY"
+    SUNDAY = "SUNDAY"
+
+
+CLIMATE_MAX_SCHEDULER_TIME: Final = "24:00"
+CLIMATE_MIN_SCHEDULER_TIME: Final = "00:00"
+CLIMATE_WEEKDAY_DICT = dict[int, dict[ScheduleSlotType, str | float]]
+CLIMATE_PROFILE_DICT = dict[WeekdayStr, CLIMATE_WEEKDAY_DICT]
+CLIMATE_RELEVANT_SLOT_TYPES: Final = (ScheduleSlotType.ENDTIME, ScheduleSlotType.TEMPERATURE)
+CLIMATE_SCHEDULE_DICT = dict[ScheduleProfile, CLIMATE_PROFILE_DICT]
+CLIMATE_SCHEDULE_SLOT_IN_RANGE: Final = range(1, 14)
+CLIMATE_SCHEDULE_SLOT_RANGE: Final = range(1, 13)
+CLIMATE_SCHEDULE_TIME_RANGE: Final = range(1441)
+CLIMATE_SIMPLE_WEEKDAY_LIST = list[dict[ScheduleSlotType, str | float]]
+CLIMATE_SIMPLE_PROFILE_DICT = dict[WeekdayStr, CLIMATE_SIMPLE_WEEKDAY_LIST]
+DEFAULT_CLIMATE_FILL_TEMPERATURE: Final = 18.0
+DEFAULT_SCHEDULE_GROUP = dict[ScheduleField, Any]
+DEFAULT_SCHEDULE_DICT = dict[int, DEFAULT_SCHEDULE_GROUP]
+RAW_SCHEDULE_DICT = dict[str, float | int]
+SCHEDULE_PATTERN: Final = re.compile(r"^\d+_WP_")
