@@ -47,47 +47,6 @@ class OperatingVoltageLevel[SensorT: float | None](CalculatedDataPoint[SensorT])
         self._type = ParameterType.FLOAT
         self._unit = "%"
 
-    def _init_data_point_fields(self) -> None:
-        """Init the data point fields."""
-        super()._init_data_point_fields()
-        self._battery_data = _get_battery_data(model=self._channel.device.model)
-
-        operating_voltage: DpSensor = self._add_data_point(
-            parameter=Parameter.OPERATING_VOLTAGE, paramset_key=ParamsetKey.VALUES, data_point_type=DpSensor
-        )
-
-        self._dp_operating_voltage: DpSensor = (
-            operating_voltage
-            if isinstance(operating_voltage, DpSensor)
-            else self._add_data_point(
-                parameter=Parameter.BATTERY_STATE, paramset_key=ParamsetKey.VALUES, data_point_type=DpSensor
-            )
-        )
-
-        low_bat_limit: DpSensor = self._add_data_point(
-            parameter=Parameter.LOW_BAT_LIMIT, paramset_key=ParamsetKey.MASTER, data_point_type=DpSensor
-        )
-
-        self._dp_low_bat_limit: DpFloat = (
-            low_bat_limit
-            if isinstance(low_bat_limit, DpFloat)
-            else self._add_device_data_point(
-                channel_address=self.channel.device.address,
-                parameter=Parameter.LOW_BAT_LIMIT,
-                paramset_key=ParamsetKey.MASTER,
-                data_point_type=DpFloat,
-            )
-        )
-
-        self._low_bat_limit_default = (
-            float(self._dp_low_bat_limit.default) if isinstance(self._dp_low_bat_limit, DpFloat) else None
-        )
-        self._voltage_max = (
-            float(_BatteryVoltage.get(self._battery_data.battery) * self._battery_data.quantity)  # type: ignore[operator]
-            if self._battery_data is not None
-            else None
-        )
-
     @staticmethod
     def is_relevant_for_model(*, channel: hmd.Channel) -> bool:
         """Return if this calculated data point is relevant for the model."""
@@ -120,6 +79,15 @@ class OperatingVoltageLevel[SensorT: float | None](CalculatedDataPoint[SensorT])
             is not None
         )
 
+    @property
+    def _low_bat_limit(self) -> float | None:
+        """Return the min value."""
+        return (
+            float(self._dp_low_bat_limit.value)
+            if self._dp_low_bat_limit is not None and self._dp_low_bat_limit.value is not None
+            else None
+        )
+
     @state_property
     def additional_information(self) -> dict[str, Any]:
         """Return additional information about the entity."""
@@ -153,12 +121,47 @@ class OperatingVoltageLevel[SensorT: float | None](CalculatedDataPoint[SensorT])
             )
         return None
 
-    @property
-    def _low_bat_limit(self) -> float | None:
-        """Return the min value."""
-        return (
-            float(self._dp_low_bat_limit.value)
-            if self._dp_low_bat_limit is not None and self._dp_low_bat_limit.value is not None
+    def _init_data_point_fields(self) -> None:
+        """Init the data point fields."""
+        super()._init_data_point_fields()
+
+        self._battery_data = _get_battery_data(model=self._channel.device.model)
+
+        operating_voltage: DpSensor[float | None] = self._add_data_point(
+            parameter=Parameter.OPERATING_VOLTAGE, paramset_key=ParamsetKey.VALUES, data_point_type=DpSensor
+        )
+
+        self._dp_operating_voltage: DpSensor[float | None] = (
+            operating_voltage
+            if isinstance(operating_voltage, DpSensor)
+            else self._add_data_point(
+                parameter=Parameter.BATTERY_STATE, paramset_key=ParamsetKey.VALUES, data_point_type=DpSensor
+            )
+        )
+
+        low_bat_limit: DpSensor[float | None] = self._add_data_point(
+            parameter=Parameter.LOW_BAT_LIMIT, paramset_key=ParamsetKey.MASTER, data_point_type=DpSensor
+        )
+
+        self._dp_low_bat_limit: DpFloat = (
+            low_bat_limit
+            if isinstance(low_bat_limit, DpFloat)
+            else self._add_device_data_point(
+                channel_address=self.channel.device.address,
+                parameter=Parameter.LOW_BAT_LIMIT,
+                paramset_key=ParamsetKey.MASTER,
+                data_point_type=DpFloat,
+            )
+        )
+
+        self._low_bat_limit_default = (
+            float(self._dp_low_bat_limit.default)
+            if isinstance(self._dp_low_bat_limit, DpFloat) and self._dp_low_bat_limit.default is not None
+            else None
+        )
+        self._voltage_max = (
+            float(_BatteryVoltage[self._battery_data.battery] * self._battery_data.quantity)
+            if self._battery_data is not None
             else None
         )
 
