@@ -11,11 +11,10 @@ from typing import Any, Final, cast
 
 import voluptuous as vol
 
-from aiohomematic import support as hms, validator as val
-from aiohomematic.const import DataPointCategory, Parameter
+from aiohomematic import i18n, support as hms, validator as val
+from aiohomematic.const import CDPD, DataPointCategory, DeviceProfile, Field, Parameter
 from aiohomematic.exceptions import AioHomematicException
 from aiohomematic.model import device as hmd
-from aiohomematic.model.custom.const import CDPD, DeviceProfile, Field
 from aiohomematic.model.custom.support import CustomConfig
 from aiohomematic.model.support import generate_unique_id
 from aiohomematic.support import extract_exc_args
@@ -592,7 +591,13 @@ def validate_custom_data_point_definition() -> Any:
     try:
         return _SCHEMA_DEVICE_DESCRIPTION(_CUSTOM_DATA_POINT_DEFINITION)
     except vol.Invalid as err:  # pragma: no cover
-        _LOGGER.error("The custom data point definition could not be validated. %s, %s", err.path, err.msg)
+        _LOGGER.error(
+            i18n.tr(
+                "log.model.custom.definition.validate_failed",
+                path=str(err.path),
+                msg=str(err.msg),
+            )
+        )
         return None
 
 
@@ -651,7 +656,10 @@ def _create_custom_data_point(
             channel.add_data_point(data_point=dp)
     except Exception as exc:
         raise AioHomematicException(
-            f"_CREATE_CUSTOM_DATA_POINT: unable to create custom data point: {extract_exc_args(exc=exc)}"
+            i18n.tr(
+                "exception.model.custom.definition.create_custom_data_point.failed",
+                reason=extract_exc_args(exc=exc),
+            )
         ) from exc
 
 
@@ -665,6 +673,7 @@ def _rebase_pri_channels(*, device_profile: DeviceProfile, custom_config: Custom
         make_ce_func=custom_config.make_ce_func,
         channels=tuple(pri_channels),
         extended=custom_config.extended,
+        schedule_channel_no=custom_config.schedule_channel_no,
     )
 
 
