@@ -9,14 +9,13 @@ from enum import IntEnum, StrEnum
 import math
 from typing import Any, Final, TypedDict, Unpack
 
-from aiohomematic.const import DataPointCategory, DataPointUsage, Parameter
+from aiohomematic.const import DataPointCategory, DataPointUsage, DeviceProfile, Field, Parameter
 from aiohomematic.model import device as hmd
 from aiohomematic.model.custom import definition as hmed
-from aiohomematic.model.custom.const import DeviceProfile, Field
 from aiohomematic.model.custom.data_point import CustomDataPoint
 from aiohomematic.model.custom.support import CustomConfig, ExtendedConfig
 from aiohomematic.model.data_point import CallParameterCollector, bind_collector
-from aiohomematic.model.generic import DpAction, DpFloat, DpInteger, DpSelect, DpSensor, GenericDataPoint
+from aiohomematic.model.generic import DpAction, DpFloat, DpInteger, DpSelect, DpSensor, GenericDataPointAny
 from aiohomematic.property_decorators import state_property
 
 _DIMMER_OFF: Final = 0.0
@@ -147,26 +146,6 @@ class CustomDpDimmer(CustomDataPoint):
     )
     _category = DataPointCategory.LIGHT
 
-    def _init_data_point_fields(self) -> None:
-        """Init the data_point fields."""
-        super()._init_data_point_fields()
-        self._dp_level: DpFloat = self._get_data_point(field=Field.LEVEL, data_point_type=DpFloat)
-        self._dp_group_level: DpSensor[float | None] = self._get_data_point(
-            field=Field.GROUP_LEVEL, data_point_type=DpSensor[float | None]
-        )
-        self._dp_on_time_value: DpAction = self._get_data_point(field=Field.ON_TIME_VALUE, data_point_type=DpAction)
-        self._dp_ramp_time_value: DpAction = self._get_data_point(field=Field.RAMP_TIME_VALUE, data_point_type=DpAction)
-
-    @state_property
-    def is_on(self) -> bool | None:
-        """Return true if dimmer is on."""
-        return self._dp_level.value is not None and self._dp_level.value > _DIMMER_OFF
-
-    @state_property
-    def brightness(self) -> int | None:
-        """Return the brightness of this light between min/max brightness."""
-        return int((self._dp_level.value or _MIN_BRIGHTNESS) * _MAX_BRIGHTNESS)
-
     @property
     def brightness_pct(self) -> int | None:
         """Return the brightness in percent of this light."""
@@ -186,16 +165,6 @@ class CustomDpDimmer(CustomDataPoint):
             return int(self._dp_group_level.value * _LEVEL_TO_BRIGHTNESS_MULTIPLIER)
         return None
 
-    @state_property
-    def color_temp_kelvin(self) -> int | None:
-        """Return the color temperature in kelvin."""
-        return None
-
-    @state_property
-    def hs_color(self) -> tuple[float, float] | None:
-        """Return the hue and saturation color value [float, float]."""
-        return None
-
     @property
     def supports_brightness(self) -> bool:
         """Flag if light supports brightness."""
@@ -221,6 +190,16 @@ class CustomDpDimmer(CustomDataPoint):
         """Flag if light supports transition."""
         return isinstance(self._dp_ramp_time_value, DpAction)
 
+    @state_property
+    def brightness(self) -> int | None:
+        """Return the brightness of this light between min/max brightness."""
+        return int((self._dp_level.value or _MIN_BRIGHTNESS) * _MAX_BRIGHTNESS)
+
+    @state_property
+    def color_temp_kelvin(self) -> int | None:
+        """Return the color temperature in kelvin."""
+        return None
+
     @state_property
     def effect(self) -> str | None:
         """Return the current effect."""
@@ -231,51 +210,15 @@ class CustomDpDimmer(CustomDataPoint):
         """Return the supported effects."""
         return None
 
-    @bind_collector()
-    async def turn_on(self, *, collector: CallParameterCollector | None = None, **kwargs: Unpack[LightOnArgs]) -> None:
-        """Turn the light on."""
-        if (on_time := kwargs.get("on_time")) is not None:
-            self.set_timer_on_time(on_time=on_time)
-        if not self.is_state_change(on=True, **kwargs):
-            return
+    @state_property
+    def hs_color(self) -> tuple[float, float] | None:
+        """Return the hue and saturation color value [float, float]."""
+        return None
 
-        if (timer := self.get_and_start_timer()) is not None:
-            await self._set_on_time_value(on_time=timer, collector=collector)
-        if ramp_time := kwargs.get("ramp_time"):
-            await self._set_ramp_time_on_value(ramp_time=ramp_time, collector=collector)
-        if not (brightness := kwargs.get("brightness", self.brightness)):
-            brightness = int(_MAX_BRIGHTNESS)
-        level = brightness / _MAX_BRIGHTNESS
-        await self._dp_level.send_value(value=level, collector=collector)
-
-    @bind_collector()
-    async def turn_off(
-        self, *, collector: CallParameterCollector | None = None, **kwargs: Unpack[LightOffArgs]
-    ) -> None:
-        """Turn the light off."""
-        self.reset_timer_on_time()
-        if not self.is_state_change(off=True, **kwargs):
-            return
-        if ramp_time := kwargs.get("ramp_time"):
-            await self._set_ramp_time_off_value(ramp_time=ramp_time, collector=collector)
-        await self._dp_level.send_value(value=_DIMMER_OFF, collector=collector)
-
-    @bind_collector()
-    async def _set_on_time_value(self, *, on_time: float, collector: CallParameterCollector | None = None) -> None:
-        """Set the on time value in seconds."""
-        await self._dp_on_time_value.send_value(value=on_time, collector=collector, do_validate=False)
-
-    async def _set_ramp_time_on_value(
-        self, *, ramp_time: float, collector: CallParameterCollector | None = None
-    ) -> None:
-        """Set the ramp time value in seconds."""
-        await self._dp_ramp_time_value.send_value(value=ramp_time, collector=collector)
-
-    async def _set_ramp_time_off_value(
-        self, *, ramp_time: float, collector: CallParameterCollector | None = None
-    ) -> None:
-        """Set the ramp time value in seconds."""
-        await self._set_ramp_time_on_value(ramp_time=ramp_time, collector=collector)
+    @state_property
+    def is_on(self) -> bool | None:
+        """Return true if dimmer is on."""
+        return self._dp_level.value is not None and self._dp_level.value > _DIMMER_OFF
 
     def is_state_change(self, **kwargs: Any) -> bool:
         """Check if the state changes due to kwargs."""
@@ -303,17 +246,69 @@ class CustomDpDimmer(CustomDataPoint):
             return True
         return super().is_state_change(**kwargs)
 
+    @bind_collector
+    async def turn_off(
+        self, *, collector: CallParameterCollector | None = None, **kwargs: Unpack[LightOffArgs]
+    ) -> None:
+        """Turn the light off."""
+        self.reset_timer_on_time()
+        if not self.is_state_change(off=True, **kwargs):
+            return
+        if ramp_time := kwargs.get("ramp_time"):
+            await self._set_ramp_time_off_value(ramp_time=ramp_time, collector=collector)
+        await self._dp_level.send_value(value=_DIMMER_OFF, collector=collector)
+
+    @bind_collector
+    async def turn_on(self, *, collector: CallParameterCollector | None = None, **kwargs: Unpack[LightOnArgs]) -> None:
+        """Turn the light on."""
+        if (on_time := kwargs.get("on_time")) is not None:
+            self.set_timer_on_time(on_time=on_time)
+        if not self.is_state_change(on=True, **kwargs):
+            return
+
+        if (timer := self.get_and_start_timer()) is not None:
+            await self._set_on_time_value(on_time=timer, collector=collector)
+        if ramp_time := kwargs.get("ramp_time"):
+            await self._set_ramp_time_on_value(ramp_time=ramp_time, collector=collector)
+        if not (brightness := kwargs.get("brightness", self.brightness)):
+            brightness = int(_MAX_BRIGHTNESS)
+        level = brightness / _MAX_BRIGHTNESS
+        await self._dp_level.send_value(value=level, collector=collector)
+
+    def _init_data_point_fields(self) -> None:
+        """Init the data_point fields."""
+        super()._init_data_point_fields()
+
+        self._dp_level: DpFloat = self._get_data_point(field=Field.LEVEL, data_point_type=DpFloat)
+        self._dp_group_level: DpSensor[float | None] = self._get_data_point(
+            field=Field.GROUP_LEVEL, data_point_type=DpSensor[float | None]
+        )
+        self._dp_on_time_value: DpAction = self._get_data_point(field=Field.ON_TIME_VALUE, data_point_type=DpAction)
+        self._dp_ramp_time_value: DpAction = self._get_data_point(field=Field.RAMP_TIME_VALUE, data_point_type=DpAction)
+
+    @bind_collector
+    async def _set_on_time_value(self, *, on_time: float, collector: CallParameterCollector | None = None) -> None:
+        """Set the on time value in seconds."""
+        await self._dp_on_time_value.send_value(value=on_time, collector=collector, do_validate=False)
+
+    async def _set_ramp_time_off_value(
+        self, *, ramp_time: float, collector: CallParameterCollector | None = None
+    ) -> None:
+        """Set the ramp time value in seconds."""
+        await self._set_ramp_time_on_value(ramp_time=ramp_time, collector=collector)
+
+    async def _set_ramp_time_on_value(
+        self, *, ramp_time: float, collector: CallParameterCollector | None = None
+    ) -> None:
+        """Set the ramp time value in seconds."""
+        await self._dp_ramp_time_value.send_value(value=ramp_time, collector=collector)
+
 
 class CustomDpColorDimmer(CustomDpDimmer):
     """Class for Homematic dimmer with color data point."""
 
     __slots__ = ("_dp_color",)
 
-    def _init_data_point_fields(self) -> None:
-        """Init the data_point fields."""
-        super()._init_data_point_fields()
-        self._dp_color: DpInteger = self._get_data_point(field=Field.COLOR, data_point_type=DpInteger)
-
     @state_property
     def hs_color(self) -> tuple[float, float] | None:
         """Return the hue and saturation color value [float, float]."""
@@ -328,7 +323,7 @@ class CustomDpColorDimmer(CustomDpDimmer):
             return color / 200 * 360, _MAX_SATURATION
         return _MIN_HUE, _MIN_SATURATION
 
-    @bind_collector()
+    @bind_collector
     async def turn_on(self, *, collector: CallParameterCollector | None = None, **kwargs: Unpack[LightOnArgs]) -> None:
         """Turn the light on."""
         if not self.is_state_change(on=True, **kwargs):
@@ -341,6 +336,12 @@ class CustomDpColorDimmer(CustomDpDimmer):
             await self._dp_color.send_value(value=color, collector=collector)
         await super().turn_on(collector=collector, **kwargs)
 
+    def _init_data_point_fields(self) -> None:
+        """Init the data_point fields."""
+        super()._init_data_point_fields()
+
+        self._dp_color: DpInteger = self._get_data_point(field=Field.COLOR, data_point_type=DpInteger)
+
 
 class CustomDpColorDimmerEffect(CustomDpColorDimmer):
     """Class for Homematic dimmer with color data point."""
@@ -357,11 +358,6 @@ class CustomDpColorDimmerEffect(CustomDpColorDimmer):
         "TV simulation",
     )
 
-    def _init_data_point_fields(self) -> None:
-        """Init the data_point fields."""
-        super()._init_data_point_fields()
-        self._dp_effect: DpInteger = self._get_data_point(field=Field.PROGRAM, data_point_type=DpInteger)
-
     @state_property
     def effect(self) -> str | None:
         """Return the current effect."""
@@ -374,7 +370,7 @@ class CustomDpColorDimmerEffect(CustomDpColorDimmer):
         """Return the supported effects."""
         return self._effects
 
-    @bind_collector()
+    @bind_collector
     async def turn_on(self, *, collector: CallParameterCollector | None = None, **kwargs: Unpack[LightOnArgs]) -> None:
         """Turn the light on."""
         if not self.is_state_change(on=True, **kwargs):
@@ -392,17 +388,18 @@ class CustomDpColorDimmerEffect(CustomDpColorDimmer):
 
         await super().turn_on(collector=collector, **kwargs)
 
+    def _init_data_point_fields(self) -> None:
+        """Init the data_point fields."""
+        super()._init_data_point_fields()
+
+        self._dp_effect: DpInteger = self._get_data_point(field=Field.PROGRAM, data_point_type=DpInteger)
+
 
 class CustomDpColorTempDimmer(CustomDpDimmer):
     """Class for Homematic dimmer with color temperature."""
 
     __slots__ = ("_dp_color_level",)
 
-    def _init_data_point_fields(self) -> None:
-        """Init the data_point fields."""
-        super()._init_data_point_fields()
-        self._dp_color_level: DpFloat = self._get_data_point(field=Field.COLOR_LEVEL, data_point_type=DpFloat)
-
     @state_property
     def color_temp_kelvin(self) -> int | None:
         """Return the color temperature in kelvin."""
@@ -410,7 +407,7 @@ class CustomDpColorTempDimmer(CustomDpDimmer):
             _MAX_KELVIN / int(_MAX_MIREDS - (_MAX_MIREDS - _MIN_MIREDS) * (self._dp_color_level.value or _DIMMER_OFF))
         )
 
-    @bind_collector()
+    @bind_collector
     async def turn_on(self, *, collector: CallParameterCollector | None = None, **kwargs: Unpack[LightOnArgs]) -> None:
         """Turn the light on."""
         if not self.is_state_change(on=True, **kwargs):
@@ -421,6 +418,12 @@ class CustomDpColorTempDimmer(CustomDpDimmer):
 
         await super().turn_on(collector=collector, **kwargs)
 
+    def _init_data_point_fields(self) -> None:
+        """Init the data_point fields."""
+        super()._init_data_point_fields()
+
+        self._dp_color_level: DpFloat = self._get_data_point(field=Field.COLOR_LEVEL, data_point_type=DpFloat)
+
 
 class CustomDpIpRGBWLight(CustomDpDimmer):
     """Class for HomematicIP HmIP-RGBW light data point."""
@@ -438,46 +441,17 @@ class CustomDpIpRGBWLight(CustomDpDimmer):
         "_dp_saturation",
     )
 
-    def _init_data_point_fields(self) -> None:
-        """Init the data_point fields."""
-        super()._init_data_point_fields()
-        self._dp_activity_state: DpSensor[str | None] = self._get_data_point(
-            field=Field.DIRECTION, data_point_type=DpSensor[str | None]
-        )
-        self._dp_color_temperature_kelvin: DpInteger = self._get_data_point(
-            field=Field.COLOR_TEMPERATURE, data_point_type=DpInteger
-        )
-        self._dp_device_operation_mode: DpSelect = self._get_data_point(
-            field=Field.DEVICE_OPERATION_MODE, data_point_type=DpSelect
-        )
-        self._dp_on_time_unit: DpAction = self._get_data_point(field=Field.ON_TIME_UNIT, data_point_type=DpAction)
-        self._dp_effect: DpAction = self._get_data_point(field=Field.EFFECT, data_point_type=DpAction)
-        self._dp_hue: DpInteger = self._get_data_point(field=Field.HUE, data_point_type=DpInteger)
-        self._dp_ramp_time_to_off_unit: DpAction = self._get_data_point(
-            field=Field.RAMP_TIME_TO_OFF_UNIT, data_point_type=DpAction
-        )
-        self._dp_ramp_time_to_off_value: DpAction = self._get_data_point(
-            field=Field.RAMP_TIME_TO_OFF_VALUE, data_point_type=DpAction
-        )
-        self._dp_ramp_time_unit: DpAction = self._get_data_point(field=Field.RAMP_TIME_UNIT, data_point_type=DpAction)
-        self._dp_saturation: DpFloat = self._get_data_point(field=Field.SATURATION, data_point_type=DpFloat)
-
-    @state_property
-    def color_temp_kelvin(self) -> int | None:
-        """Return the color temperature in kelvin."""
-        if not self._dp_color_temperature_kelvin.value:
-            return None
-        return self._dp_color_temperature_kelvin.value
-
-    @state_property
-    def hs_color(self) -> tuple[float, float] | None:
-        """Return the hue and saturation color value [float, float]."""
-        if self._dp_hue.value is not None and self._dp_saturation.value is not None:
-            return self._dp_hue.value, self._dp_saturation.value * _SATURATION_MULTIPLIER
-        return None
+    @property
+    def _device_operation_mode(self) -> _DeviceOperationMode:
+        """Return the device operation mode."""
+        try:
+            return _DeviceOperationMode(str(self._dp_device_operation_mode.value))
+        except Exception:
+            # Fallback to a sensible default if the value is not set or unexpected
+            return _DeviceOperationMode.RGBW
 
     @property
-    def _relevant_data_points(self) -> tuple[GenericDataPoint, ...]:
+    def _relevant_data_points(self) -> tuple[GenericDataPointAny, ...]:
         """Returns the list of relevant data points. To be overridden by subclasses."""
         if self._device_operation_mode == _DeviceOperationMode.RGBW:
             return (
@@ -528,12 +502,35 @@ class CustomDpIpRGBWLight(CustomDpDimmer):
             return DataPointUsage.NO_CREATE
         return self._get_data_point_usage()
 
+    @state_property
+    def color_temp_kelvin(self) -> int | None:
+        """Return the color temperature in kelvin."""
+        if not self._dp_color_temperature_kelvin.value:
+            return None
+        return self._dp_color_temperature_kelvin.value
+
     @state_property
     def effects(self) -> tuple[str, ...] | None:
         """Return the supported effects."""
         return self._dp_effect.values or ()
 
-    @bind_collector()
+    @state_property
+    def hs_color(self) -> tuple[float, float] | None:
+        """Return the hue and saturation color value [float, float]."""
+        if self._dp_hue.value is not None and self._dp_saturation.value is not None:
+            return self._dp_hue.value, self._dp_saturation.value * _SATURATION_MULTIPLIER
+        return None
+
+    @bind_collector
+    async def turn_off(
+        self, *, collector: CallParameterCollector | None = None, **kwargs: Unpack[LightOffArgs]
+    ) -> None:
+        """Turn the light off."""
+        if kwargs.get("on_time") is None and kwargs.get("ramp_time"):
+            await self._set_on_time_value(on_time=_NOT_USED, collector=collector)
+        await super().turn_off(collector=collector, **kwargs)
+
+    @bind_collector
     async def turn_on(self, *, collector: CallParameterCollector | None = None, **kwargs: Unpack[LightOnArgs]) -> None:
         """Turn the light on."""
         if on_time := (kwargs.get("on_time") or self.get_and_start_timer()):
@@ -554,23 +551,32 @@ class CustomDpIpRGBWLight(CustomDpDimmer):
 
         await super().turn_on(collector=collector, **kwargs)
 
-    @bind_collector()
-    async def turn_off(
-        self, *, collector: CallParameterCollector | None = None, **kwargs: Unpack[LightOffArgs]
-    ) -> None:
-        """Turn the light off."""
-        if kwargs.get("on_time") is None and kwargs.get("ramp_time"):
-            await self._set_on_time_value(on_time=_NOT_USED, collector=collector)
-        await super().turn_off(collector=collector, **kwargs)
+    def _init_data_point_fields(self) -> None:
+        """Init the data_point fields."""
+        super()._init_data_point_fields()
 
-    @property
-    def _device_operation_mode(self) -> _DeviceOperationMode:
-        """Return the device operation mode."""
-        if (mode := self._dp_device_operation_mode.value) is None:
-            return _DeviceOperationMode.RGBW
-        return _DeviceOperationMode(mode)
+        self._dp_activity_state: DpSensor[str | None] = self._get_data_point(
+            field=Field.DIRECTION, data_point_type=DpSensor[str | None]
+        )
+        self._dp_color_temperature_kelvin: DpInteger = self._get_data_point(
+            field=Field.COLOR_TEMPERATURE, data_point_type=DpInteger
+        )
+        self._dp_device_operation_mode: DpSelect = self._get_data_point(
+            field=Field.DEVICE_OPERATION_MODE, data_point_type=DpSelect
+        )
+        self._dp_on_time_unit: DpAction = self._get_data_point(field=Field.ON_TIME_UNIT, data_point_type=DpAction)
+        self._dp_effect: DpAction = self._get_data_point(field=Field.EFFECT, data_point_type=DpAction)
+        self._dp_hue: DpInteger = self._get_data_point(field=Field.HUE, data_point_type=DpInteger)
+        self._dp_ramp_time_to_off_unit: DpAction = self._get_data_point(
+            field=Field.RAMP_TIME_TO_OFF_UNIT, data_point_type=DpAction
+        )
+        self._dp_ramp_time_to_off_value: DpAction = self._get_data_point(
+            field=Field.RAMP_TIME_TO_OFF_VALUE, data_point_type=DpAction
+        )
+        self._dp_ramp_time_unit: DpAction = self._get_data_point(field=Field.RAMP_TIME_UNIT, data_point_type=DpAction)
+        self._dp_saturation: DpFloat = self._get_data_point(field=Field.SATURATION, data_point_type=DpFloat)
 
-    @bind_collector()
+    @bind_collector
     async def _set_on_time_value(self, *, on_time: float, collector: CallParameterCollector | None = None) -> None:
         """Set the on time value in seconds."""
         on_time, on_time_unit = _recalc_unit_timer(time=on_time)
@@ -578,7 +584,7 @@ class CustomDpIpRGBWLight(CustomDpDimmer):
             await self._dp_on_time_unit.send_value(value=on_time_unit, collector=collector)
         await self._dp_on_time_value.send_value(value=float(on_time), collector=collector)
 
-    async def _set_ramp_time_on_value(
+    async def _set_ramp_time_off_value(
         self, *, ramp_time: float, collector: CallParameterCollector | None = None
     ) -> None:
         """Set the ramp time value in seconds."""
@@ -587,7 +593,7 @@ class CustomDpIpRGBWLight(CustomDpDimmer):
             await self._dp_ramp_time_unit.send_value(value=ramp_time_unit, collector=collector)
         await self._dp_ramp_time_value.send_value(value=float(ramp_time), collector=collector)
 
-    async def _set_ramp_time_off_value(
+    async def _set_ramp_time_on_value(
         self, *, ramp_time: float, collector: CallParameterCollector | None = None
     ) -> None:
         """Set the ramp time value in seconds."""
@@ -611,23 +617,10 @@ class CustomDpIpDrgDaliLight(CustomDpDimmer):
         "_dp_saturation",
     )
 
-    def _init_data_point_fields(self) -> None:
-        """Init the data_point fields."""
-        super()._init_data_point_fields()
-        self._dp_color_temperature_kelvin: DpInteger = self._get_data_point(
-            field=Field.COLOR_TEMPERATURE, data_point_type=DpInteger
-        )
-        self._dp_on_time_unit: DpAction = self._get_data_point(field=Field.ON_TIME_UNIT, data_point_type=DpAction)
-        self._dp_effect: DpAction = self._get_data_point(field=Field.EFFECT, data_point_type=DpAction)
-        self._dp_hue: DpInteger = self._get_data_point(field=Field.HUE, data_point_type=DpInteger)
-        self._dp_ramp_time_to_off_unit: DpAction = self._get_data_point(
-            field=Field.RAMP_TIME_TO_OFF_UNIT, data_point_type=DpAction
-        )
-        self._dp_ramp_time_to_off_value: DpAction = self._get_data_point(
-            field=Field.RAMP_TIME_TO_OFF_VALUE, data_point_type=DpAction
-        )
-        self._dp_ramp_time_unit: DpAction = self._get_data_point(field=Field.RAMP_TIME_UNIT, data_point_type=DpAction)
-        self._dp_saturation: DpFloat = self._get_data_point(field=Field.SATURATION, data_point_type=DpFloat)
+    @property
+    def _relevant_data_points(self) -> tuple[GenericDataPointAny, ...]:
+        """Returns the list of relevant data points. To be overridden by subclasses."""
+        return (self._dp_level,)
 
     @state_property
     def color_temp_kelvin(self) -> int | None:
@@ -636,6 +629,11 @@ class CustomDpIpDrgDaliLight(CustomDpDimmer):
             return None
         return self._dp_color_temperature_kelvin.value
 
+    @state_property
+    def effects(self) -> tuple[str, ...] | None:
+        """Return the supported effects."""
+        return self._dp_effect.values or ()
+
     @state_property
     def hs_color(self) -> tuple[float, float] | None:
         """Return the hue and saturation color value [float, float]."""
@@ -643,17 +641,7 @@ class CustomDpIpDrgDaliLight(CustomDpDimmer):
             return self._dp_hue.value, self._dp_saturation.value * _SATURATION_MULTIPLIER
         return None
 
-    @property
-    def _relevant_data_points(self) -> tuple[GenericDataPoint, ...]:
-        """Returns the list of relevant data points. To be overridden by subclasses."""
-        return (self._dp_level,)
-
-    @state_property
-    def effects(self) -> tuple[str, ...] | None:
-        """Return the supported effects."""
-        return self._dp_effect.values or ()
-
-    @bind_collector()
+    @bind_collector
     async def turn_on(self, *, collector: CallParameterCollector | None = None, **kwargs: Unpack[LightOnArgs]) -> None:
         """Turn the light on."""
         if not self.is_state_change(on=True, **kwargs):
@@ -672,7 +660,26 @@ class CustomDpIpDrgDaliLight(CustomDpDimmer):
 
         await super().turn_on(collector=collector, **kwargs)
 
-    @bind_collector()
+    def _init_data_point_fields(self) -> None:
+        """Init the data_point fields."""
+        super()._init_data_point_fields()
+
+        self._dp_color_temperature_kelvin: DpInteger = self._get_data_point(
+            field=Field.COLOR_TEMPERATURE, data_point_type=DpInteger
+        )
+        self._dp_on_time_unit: DpAction = self._get_data_point(field=Field.ON_TIME_UNIT, data_point_type=DpAction)
+        self._dp_effect: DpAction = self._get_data_point(field=Field.EFFECT, data_point_type=DpAction)
+        self._dp_hue: DpInteger = self._get_data_point(field=Field.HUE, data_point_type=DpInteger)
+        self._dp_ramp_time_to_off_unit: DpAction = self._get_data_point(
+            field=Field.RAMP_TIME_TO_OFF_UNIT, data_point_type=DpAction
+        )
+        self._dp_ramp_time_to_off_value: DpAction = self._get_data_point(
+            field=Field.RAMP_TIME_TO_OFF_VALUE, data_point_type=DpAction
+        )
+        self._dp_ramp_time_unit: DpAction = self._get_data_point(field=Field.RAMP_TIME_UNIT, data_point_type=DpAction)
+        self._dp_saturation: DpFloat = self._get_data_point(field=Field.SATURATION, data_point_type=DpFloat)
+
+    @bind_collector
     async def _set_on_time_value(self, *, on_time: float, collector: CallParameterCollector | None = None) -> None:
         """Set the on time value in seconds."""
         on_time, on_time_unit = _recalc_unit_timer(time=on_time)
@@ -680,7 +687,7 @@ class CustomDpIpDrgDaliLight(CustomDpDimmer):
             await self._dp_on_time_unit.send_value(value=on_time_unit, collector=collector)
         await self._dp_on_time_value.send_value(value=float(on_time), collector=collector)
 
-    async def _set_ramp_time_on_value(
+    async def _set_ramp_time_off_value(
         self, *, ramp_time: float, collector: CallParameterCollector | None = None
     ) -> None:
         """Set the ramp time value in seconds."""
@@ -689,7 +696,7 @@ class CustomDpIpDrgDaliLight(CustomDpDimmer):
             await self._dp_ramp_time_unit.send_value(value=ramp_time_unit, collector=collector)
         await self._dp_ramp_time_value.send_value(value=float(ramp_time), collector=collector)
 
-    async def _set_ramp_time_off_value(
+    async def _set_ramp_time_on_value(
         self, *, ramp_time: float, collector: CallParameterCollector | None = None
     ) -> None:
         """Set the ramp time value in seconds."""
@@ -711,37 +718,29 @@ class CustomDpIpFixedColorLight(CustomDpDimmer):
         "_effect_list",
     )
 
-    @state_property
-    def color_name(self) -> str | None:
-        """Return the name of the color."""
-        return self._dp_color.value
-
     @property
     def channel_color_name(self) -> str | None:
         """Return the name of the channel color."""
         return self._dp_channel_color.value
 
-    def _init_data_point_fields(self) -> None:
-        """Init the data_point fields."""
-        super()._init_data_point_fields()
-        self._dp_color: DpSelect = self._get_data_point(field=Field.COLOR, data_point_type=DpSelect)
-        self._dp_channel_color: DpSensor[str | None] = self._get_data_point(
-            field=Field.CHANNEL_COLOR, data_point_type=DpSensor[str | None]
-        )
-        self._dp_on_time_unit: DpAction = self._get_data_point(field=Field.ON_TIME_UNIT, data_point_type=DpAction)
-        self._dp_ramp_time_unit: DpAction = self._get_data_point(field=Field.RAMP_TIME_UNIT, data_point_type=DpAction)
-        self._dp_effect: DpSelect = self._get_data_point(field=Field.COLOR_BEHAVIOUR, data_point_type=DpSelect)
-        self._effect_list = (
-            tuple(str(item) for item in self._dp_effect.values if item not in _EXCLUDE_FROM_COLOR_BEHAVIOUR)
-            if (self._dp_effect and self._dp_effect.values)
-            else ()
-        )
+    @property
+    def channel_hs_color(self) -> tuple[float, float] | None:
+        """Return the channel hue and saturation color value [float, float]."""
+        if self._dp_channel_color.value is not None:
+            return _FIXED_COLOR_SWITCHER.get(self._dp_channel_color.value, (_MIN_HUE, _MIN_SATURATION))
+        return None
+
+    @state_property
+    def color_name(self) -> str | None:
+        """Return the name of the color."""
+        val = self._dp_color.value
+        return val if isinstance(val, str) else None
 
     @state_property
     def effect(self) -> str | None:
         """Return the current effect."""
         if (effect := self._dp_effect.value) is not None and effect in self._effect_list:
-            return effect
+            return effect if isinstance(effect, str) else None
         return None
 
     @state_property
@@ -754,19 +753,13 @@ class CustomDpIpFixedColorLight(CustomDpDimmer):
         """Return the hue and saturation color value [float, float]."""
         if (
             self._dp_color.value is not None
+            and isinstance(self._dp_color.value, str)
             and (hs_color := _FIXED_COLOR_SWITCHER.get(self._dp_color.value)) is not None
         ):
             return hs_color
         return _MIN_HUE, _MIN_SATURATION
 
-    @property
-    def channel_hs_color(self) -> tuple[float, float] | None:
-        """Return the channel hue and saturation color value [float, float]."""
-        if self._dp_channel_color.value is not None:
-            return _FIXED_COLOR_SWITCHER.get(self._dp_channel_color.value, (_MIN_HUE, _MIN_SATURATION))
-        return None
-
-    @bind_collector()
+    @bind_collector
     async def turn_on(self, *, collector: CallParameterCollector | None = None, **kwargs: Unpack[LightOnArgs]) -> None:
         """Turn the light on."""
         if not self.is_state_change(on=True, **kwargs):
@@ -785,7 +778,24 @@ class CustomDpIpFixedColorLight(CustomDpDimmer):
 
         await super().turn_on(collector=collector, **kwargs)
 
-    @bind_collector()
+    def _init_data_point_fields(self) -> None:
+        """Init the data_point fields."""
+        super()._init_data_point_fields()
+
+        self._dp_color: DpSelect = self._get_data_point(field=Field.COLOR, data_point_type=DpSelect)
+        self._dp_channel_color: DpSensor[str | None] = self._get_data_point(
+            field=Field.CHANNEL_COLOR, data_point_type=DpSensor[str | None]
+        )
+        self._dp_on_time_unit: DpAction = self._get_data_point(field=Field.ON_TIME_UNIT, data_point_type=DpAction)
+        self._dp_ramp_time_unit: DpAction = self._get_data_point(field=Field.RAMP_TIME_UNIT, data_point_type=DpAction)
+        self._dp_effect: DpSelect = self._get_data_point(field=Field.COLOR_BEHAVIOUR, data_point_type=DpSelect)
+        self._effect_list = (
+            tuple(str(item) for item in self._dp_effect.values if item not in _EXCLUDE_FROM_COLOR_BEHAVIOUR)
+            if (self._dp_effect and self._dp_effect.values)
+            else ()
+        )
+
+    @bind_collector
     async def _set_on_time_value(self, *, on_time: float, collector: CallParameterCollector | None = None) -> None:
         """Set the on time value in seconds."""
         on_time, on_time_unit = _recalc_unit_timer(time=on_time)
