@@ -52,7 +52,7 @@ from collections.abc import Mapping
 import logging
 from typing import Final
 
-from aiohomematic import support as hms
+from aiohomematic import i18n, support as hms
 from aiohomematic.const import (
     CLICK_EVENTS,
     VIRTUAL_REMOTE_MODELS,
@@ -68,7 +68,8 @@ from aiohomematic.model import device as hmd
 from aiohomematic.model.generic.action import DpAction
 from aiohomematic.model.generic.binary_sensor import DpBinarySensor
 from aiohomematic.model.generic.button import DpButton
-from aiohomematic.model.generic.data_point import GenericDataPoint
+from aiohomematic.model.generic.data_point import GenericDataPoint, GenericDataPointAny
+from aiohomematic.model.generic.dummy import DpDummy
 from aiohomematic.model.generic.number import BaseDpNumber, DpFloat, DpInteger
 from aiohomematic.model.generic.select import DpSelect
 from aiohomematic.model.generic.sensor import DpSensor
@@ -81,6 +82,7 @@ __all__ = [
     "DpAction",
     "DpBinarySensor",
     "DpButton",
+    "DpDummy",
     "DpFloat",
     "DpInteger",
     "DpSelect",
@@ -88,6 +90,7 @@ __all__ = [
     "DpSwitch",
     "DpText",
     "GenericDataPoint",
+    "GenericDataPointAny",
     "create_data_point_and_append_to_channel",
 ]
 
@@ -134,11 +137,11 @@ def create_data_point_and_append_to_channel(
 
 def _determine_data_point_type(
     *, channel: hmd.Channel, parameter: str, parameter_data: ParameterData
-) -> type[GenericDataPoint] | None:
+) -> type[GenericDataPointAny] | None:
     """Determine the type of data point based on parameter and operations."""
     p_type = parameter_data["TYPE"]
     p_operations = parameter_data["OPERATIONS"]
-    dp_t: type[GenericDataPoint] | None = None
+    dp_t: type[GenericDataPointAny] | None = None
     if p_operations & Operations.WRITE:
         if p_type == ParameterType.ACTION:
             if p_operations == Operations.WRITE:
@@ -175,12 +178,12 @@ def _determine_data_point_type(
 
 def _safe_create_data_point(
     *,
-    dp_t: type[GenericDataPoint],
+    dp_t: type[GenericDataPointAny],
     channel: hmd.Channel,
     paramset_key: ParamsetKey,
     parameter: str,
     parameter_data: ParameterData,
-) -> GenericDataPoint:
+) -> GenericDataPointAny:
     """Safely create a data point and handle exceptions."""
     try:
         return dp_t(
@@ -191,11 +194,14 @@ def _safe_create_data_point(
         )
     except Exception as exc:
         raise AioHomematicException(
-            f"CREATE_DATA_POINT_AND_APPEND_TO_CHANNEL: Unable to create data_point:{hms.extract_exc_args(exc=exc)}"
+            i18n.tr(
+                "exception.model.generic.create_data_point.failed",
+                reason=hms.extract_exc_args(exc=exc),
+            )
         ) from exc
 
 
-def _check_switch_to_sensor(*, data_point: GenericDataPoint) -> bool:
+def _check_switch_to_sensor(*, data_point: GenericDataPointAny) -> bool:
     """Check if parameter of a device should be wrapped to a different category."""
     if data_point.device.central.parameter_visibility.parameter_is_un_ignored(
         channel=data_point.channel,
