@@ -14,6 +14,7 @@ from typing import Any, Final
 from aiohomematic import central as hmcu
 from aiohomematic.const import (
     ADDRESS_SEPARATOR,
+    CDPD,
     PROGRAM_ADDRESS,
     PROGRAM_SET_PATH_ROOT,
     PROGRAM_STATE_PATH_ROOT,
@@ -32,13 +33,11 @@ from aiohomematic.const import (
     ParameterType,
 )
 from aiohomematic.model import device as hmd
-from aiohomematic.model.custom.const import CDPD
 from aiohomematic.support import to_bool
 
 __all__ = [
     "ChannelNameData",
     "DataPointNameData",
-    "GenericParameterType",
     "check_channel_is_the_only_primary_channel",
     "convert_value",
     "generate_channel_unique_id",
@@ -54,8 +53,6 @@ __all__ = [
 ]
 _LOGGER: Final = logging.getLogger(__name__)
 
-type GenericParameterType = bool | int | float | str | None
-
 # dict with binary_sensor relevant value lists and the corresponding TRUE value
 _BINARY_SENSOR_TRUE_VALUE_DICT_FOR_VALUE_LIST: Final[Mapping[tuple[str, ...], str]] = {
     ("CLOSED", "OPEN"): "OPEN",
@@ -81,11 +78,6 @@ class ChannelNameData:
         self.full_name = f"{device_name} {self.channel_name}".strip() if self.channel_name else device_name
         self.sub_device_name = channel_name if channel_name else device_name
 
-    @staticmethod
-    def empty() -> ChannelNameData:
-        """Return an empty DataPointNameData."""
-        return ChannelNameData(device_name="", channel_name="")
-
     @staticmethod
     def _get_channel_name(*, device_name: str, channel_name: str) -> str:
         """Return the channel_name of the data_point only name."""
@@ -96,6 +88,11 @@ class ChannelNameData:
             return c_name
         return channel_name.strip()
 
+    @staticmethod
+    def empty() -> ChannelNameData:
+        """Return an empty DataPointNameData."""
+        return ChannelNameData(device_name="", channel_name="")
+
 
 class DataPointNameData(ChannelNameData):
     """Dataclass for data_point name parts."""
@@ -115,11 +112,6 @@ class DataPointNameData(ChannelNameData):
         self.full_name = f"{device_name} {self.name}".strip() if self.name else device_name
         self.parameter_name = parameter_name
 
-    @staticmethod
-    def empty() -> DataPointNameData:
-        """Return an empty DataPointNameData."""
-        return DataPointNameData(device_name="", channel_name="")
-
     @staticmethod
     def _get_channel_parameter_name(*, channel_name: str, parameter_name: str | None) -> str:
         """Return the channel parameter name of the data_point."""
@@ -127,6 +119,11 @@ class DataPointNameData(ChannelNameData):
             return f"{channel_name} {parameter_name}".strip()
         return channel_name.strip()
 
+    @staticmethod
+    def empty() -> DataPointNameData:
+        """Return an empty DataPointNameData."""
+        return DataPointNameData(device_name="", channel_name="")
+
     def _get_data_point_name(self, *, device_name: str, channel_name: str, parameter_name: str | None) -> str:
         """Return the name of the data_point only name."""
         channel_parameter_name = self._get_channel_parameter_name(
